@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 
-"""API Manager."""
+"""API Extension."""
 
 from flask import Blueprint, jsonify, request
 from os.path import abspath, dirname, join
@@ -175,8 +175,11 @@ class ExpandedBase(Cacheable, Loggable):
     return columns
 
   @classmethod
-  def get_relationships(cls):
-    return class_mapper(cls).relationships
+  def get_relationships(cls, show_private=False):
+    rels =  class_mapper(cls).relationships.values()
+    if not show_private:
+      rels = [rel for rel in rels if not rel.key.startswith('_')]
+    return rels
 
   @classmethod
   def get_related_models(cls):
@@ -200,9 +203,9 @@ class APIError(HTTPException):
   def __repr__(self):
     return '<APIError %r: %r>' % (self.message, self.content)
 
-class APIManager(object):
+class API(object):
 
-  """Main API manager.
+  """Main API extension.
 
   Handles the creation and registration of all API views. Available options:
 
@@ -218,20 +221,20 @@ class APIManager(object):
 
   Models can be added in two ways. Either individually::
     
-    manager.add_model(Model)
+    api.add_model(Model)
 
   or globally::
 
-    manager.add_all_models()
+    api.add_all_models()
 
   Both functions accept the same additional options (cf. their respective doc).
 
   It also exposes the `authorize` and `validate` decorators.
 
   Once all the models have been added along with (optionally) the authorize and
-  validate functions, the manager should be registered with the project::
+  validate functions, the API extension should be registered with the project::
 
-    current_project.register_manager(manager)
+    current_project.register_extension(extension)
 
   """
 
@@ -254,7 +257,7 @@ class APIManager(object):
     for k, v in kwargs.items():
       self.config[k.upper()] = v
     self.Models = {}
-    APIView._manager = self
+    APIView._extension = self
 
   def add_model(self, Model, relationships=None, allow_put_many=None,
                 methods=None):
@@ -340,7 +343,7 @@ class APIManager(object):
       col_methods = set(['GET']) & methods
     rel_methods = set(['GET']) & methods
     if rel_methods:
-      for rel in Model.get_relationships().values():
+      for rel in Model.get_relationships():
         if rel.key in relationships and rel.uselist:
           views.extend([
             ModelView(Model=Model, relationship=rel, methods=rel_methods),
@@ -366,7 +369,7 @@ class APIManager(object):
       if batch is None: batch = self.config['ALLOW_PUT_MANY']
       if rels is None: rels = self.config['RELATIONSHIPS']
       if rels is True:
-        rels = set(Model.get_relationships().keys())
+        rels = set([r.key for r in Model.get_relationships()])
       elif rels is False:
         rels = set()
       self.Models[Model.__name__] = (Model, methods, rels, batch)
@@ -391,7 +394,7 @@ class APIView(object):
 
   __all__ = []
 
-  _manager = None
+  _extension = None
 
   Model = None
   relationship = None
@@ -433,32 +436,32 @@ class APIView(object):
     return [
       r for r in self.Model.get_relationships()
       if r.uselist
-      if r.key in self._manager.Models[self.Model.__name__][2]
+      if r.key in self._extension.Models[self.Model.__name__][2]
     ]
 
   @property
   def authorized_methods(self):
     return set(
       method for method in self.methods 
-      if self._manager._authorize(self.Model, self.relationship, method)
+      if self.is_authorized(method)
     )
 
   @property
   def defaults(self):
-    return self._manager.config
+    return self._extension.config
 
   def is_validated(self, json):
     """Validate changes."""
-    if not self._manager._validate:
+    if not self._extension._validate:
       return True
     return self._mananager._validate(self.Model, json, request.method)
 
-  def is_authorized(self):
-    if not self._manager._authorize:
+  def is_authorized(self, method=None):
+    if method is None:
+      method = request.method
+    if not self._extension._authorize:
       return True
-    return self._manager._authorize(
-      self.Model, self.relationship, request.method
-    )
+    return self._extension._authorize(self.Model, self.relationship, method)
 
   def _parse_params(self):
     return request.args
