@@ -88,21 +88,21 @@ class Project(object):
     self.celery = None
     self.session = None
     self._engine = None
-    self._managers = []
+    self._extensions = []
     self._before_startup = []
 
   def __repr__(self):
     return '<Project %r, %r>' % (self.config['PROJECT']['NAME'], self.root_dir)
 
-  def register_manager(self, manager, config_section=None):
-    """Register a manager."""
-    self._managers.append((manager, config_section))
+  def register_extension(self, extension, config_section=None):
+    """Register an extension."""
+    self._extensions.append((extension, config_section))
 
   def before_startup(self, func):
     """Decorator, hook to run a function right before project starts."""
     self._before_startup.append(func)
 
-  def make(self, app=False, celery=False):
+  def _make(self, app=False, celery=False):
     """Create all project components."""
     # core
     for mod in  ['app', 'celery']:
@@ -123,20 +123,20 @@ class Project(object):
       @task_postrun.connect
       def task_postrun_handler(*args, **kwargs):
         self._dismantle_database_connections()
-    # managers
-    for manager, config_section in self._managers or []:
+    # extensions
+    for extension, config_section in self._extensions or []:
       if config_section:
         for k, v in self.config[config_section].items():
-          manager.config[k] = v
-      manager._before_register(self)
-      self.app.register_blueprint(manager.blueprint)
-      manager._after_register(self)
+          extension.config[k] = v
+      extension._before_register(self)
+      self.app.register_blueprint(extension.blueprint)
+      extension._after_register(self)
     # final hook
     for func in self._before_startup or []:
       func(self)
 
   def _dismantle_database_connections(self, **kwrds):
-    """Remove database connection.
+    """Remove database connections.
 
     Has to be called after app request/job terminates or connections
     will leak.
@@ -176,9 +176,9 @@ class Project(object):
     return conf
 
   @classmethod
-  def get_current_project(cls):
+  def _get_current_project(cls):
     """Hook for ``current_project`` proxy."""
     return Project.__current__
 
-current_project = LocalProxy(lambda: Project.get_current_project())
+current_project = LocalProxy(lambda: Project._get_current_project())
 
